@@ -93,6 +93,13 @@ web_optional: Dict[str, Any] = {
     "client_secret_env": "DISCORD_CLIENT_SECRET",  # name of environment variable for discord client secret
     "discord_webhook_env": "DISCORD_WEBHOOK_URL",  # webhook url for discord notification log
     "verification_server": None,  # invite to special discord server for people adding images, default to support server
+    "disable_upload": False,  # disable user uploads
+    "disable_validation": False,  # disable validation
+    "validation_thresholds": {  # number of flags of each type to move the image on during validation
+        "invalid": 3,
+        "duplicate": 3,
+        "valid": 3,
+    },
 }
 
 options: Dict[str, Any] = {
